<?php
/*
 * @Author        : Qinver
 * @Url           : zibll.com
 * @Date          : 2022-04-10 20:18:56
 * @LastEditTime: 2023-10-20 22:35:01
 * @Email         : 770349780@qq.com
 * @Project       : Zibll子比主题
 * @Description   : 一款极其优雅的Wordpress主题
 * @Read me       : 感谢您使用子比主题，主题源码有详细的注释，支持二次开发。
 * @Remind        : 使用盗版主题会存在各种未知风险。支持正版，从我做起！
 */

function zib_get_post_more_dropdown($post, $class = '', $con_class = 'but cir post-drop-meta', $con = '', $direction = 'down')
{
    if (!is_object($post)) {
        $post = get_post($post);
    }
    if (empty($post->ID)) {
        return;
    }

    $con       = $con ? $con : zib_get_svg('menu_2');
    $class     = $class ? ' ' . $class : '';
    $con_class = $con_class ? ' class="' . $con_class . '"' : '';
    $action    = '';

    $user_ban = zib_get_edit_user_ban_link($post->post_author, '', '<i class="fa fa-ban mr6 fa-fw c-red"></i>禁封用户');
    if (!$user_ban) {
        $user_ban = zib_get_report_link($post->post_author, get_permalink($post), '', '<i class="fa fa-exclamation-triangle mr6 fa-fw c-red"></i>举报内容');
    }
    $action .= $user_ban ? '<li>' . $user_ban . '</li>' : '';

    //编辑
    $edit = zib_get_post_edit_link($post, '', '<i class="fa fa-fw fa-edit mr6"></i>编辑文章');
    $action .= $edit ? '<li>' . $edit . '</li>' : '';

    //删除
    $del = zib_bbs_post_delete_link($post, 'c-red', '<i class="fa fa-trash-o mr6 fa-fw"></i>删除文章');
    $action .= $del ? '<li>' . $del . '</li>' : '';

    if (!$action) {
        return;
    }

    $html = '<div class="drop' . $direction . ' more-dropup' . $class . '">';
    $html .= '<a href="javascript:;"' . $con_class . ' data-toggle="dropdown">' . $con . '</a>';
    $html .= '<ul class="dropdown-menu">';
    $html .= $action;
    $html .= '</ul>';
    $html .= '</div>';
    return $html;
}

/**
 * @description: 获取前台编辑文章的按钮
 * @param {*} $post
 * @param {*} $class
 * @param {*} $con
 * @return {*}
 */
function zib_get_post_edit_link($post = null, $class = "but c-blue", $con = '编辑文章')
{
    if (!_pz('post_article_s', true)) {
        return;
    }

    if (!is_object($post)) {
        $post = get_post($post);
    }
    if (empty($post->ID)) {
        return;
    }

    if (!zib_current_user_can('new_post_edit', $post)) {
        return;
    }

    $url = zib_get_new_post_url($post->ID);

    return '<a href="' . $url . '" class="' . $class . '">' . $con . '</a>';
}

/**
 * @description: 获取前台投稿链接
 * @param {*}
 * @return {*}
 */
function zib_get_new_post_url($edit = 0)
{

    if (!_pz('post_article_s', true)) {
        return;
    }

    $url = zib_get_template_page_url('pages/newposts.php');
    if ($edit) {
        $url = add_query_arg('edit', $edit, $url);
    }

    return $url;
}

/**
 * @description: 获取删除帖子的连接按钮
 * @param {*} $posts_id
 * @param {*} $class
 * @param {*} $con
 * @param {*} $tag
 * @return {*} zib_get_refresh_modal_link()
 */
function zib_bbs_post_delete_link($post = null, $class = '', $con = '<i class="fa fa-trash-o fa-fw"></i>删除', $tag = 'a')
{
    if (!_pz('post_article_s', true)) {
        return;
    }

    if (!is_object($post)) {
        $post = get_post($post);
    }

    if (empty($post->ID)) {
        return;
    }

    if (!zib_current_user_can('new_post_delete', $post) || 'trash' === $post->post_status) {
        return;
    }

    $url_var = array(
        'action' => 'post_delete_modal',
        'id'     => $post->ID,
    );

    $args = array(
        'tag'           => $tag,
        'class'         => $class,
        'data_class'    => 'modal-mini',
        'height'        => 240,
        'mobile_bottom' => true,
        'text'          => $con,
        'query_arg'     => $url_var,
    );

    //每次都刷新的modal
    return zib_get_refresh_modal_link($args);
}

//文章多重筛选代码
//通过pre_get_posts钩子筛选
add_action('pre_get_posts', 'zib_sift_posts_per_page', 999);
function zib_sift_posts_per_page($query)
{
    //is_category()即为分类页面有效，自行更换。
    //$query->is_main_query()使得仅对默认的页面主查询有效
    //!is_admin()避免影响后台文章列表

    if ((is_category() || is_tag() || is_home() || is_tax('topics')) && $query->is_main_query() && !is_admin()) {
        // 分类
        if (isset($_GET['cat'])) {
            $cat = $_GET['cat'];
            $query->set('cat', $cat);
        }
        //  标签
        if (isset($_GET['tag'])) {
            $tag = $_GET['tag'];
            $query->set('tag', $tag);
        }
        // 自定义分类法：taxonomy  topics
        if (isset($_GET['topics'])) {
            $array_temp = array(array('taxonomy' => 'topics', 'terms' => preg_split("/,|，|\s|\n/", $_GET['topics'])));
            $query->set('tax_query', $array_temp);
        }

        // 自定义字段：mate type
        if (isset($_GET['type'])) {
            $array_temp = array('key' => 'type', 'value' => $_GET['type'], 'compare' => '=');
        }

        $filter_args = zib_get_custom_filter_args();
        foreach ($filter_args as $filters) {

            if (!empty($_GET[$filters['key']])) {

                $meta_query = $query->get('meta_query');

                $filters_meta_query = array(
                    'key'     => $filters['key'],
                    'value'   => esc_sql($_GET[$filters['key']]),
                    'compare' => 'LIKE',
                );

                $meta_query   = is_array($meta_query) ? $meta_query : array();
                $meta_query[] = $filters_meta_query;

                $query->set('meta_query', $meta_query);
            }
        }
    }
}

//文章排序
//通过pre_get_posts钩子筛选
add_action('pre_get_posts', 'zib_sift_posts_per_orde', 9999);
function zib_sift_posts_per_orde($query)
{
    //正反顺序
    if (isset($_GET['order']) && $query->is_main_query() && !is_admin()) {
        $order = 'DESC' == $_GET['order'] ? 'DESC' : 'ASC';
        $query->set('order', $order);
    }
    //按照什么排序
    if (isset($_GET['orderby']) && $query->is_main_query() && !is_admin()) {
        $orderby           = $_GET['orderby'];
        $orderby_keys      = zib_get_query_mate_orderby_keys();
        $mate_orderbys     = $orderby_keys['value'];
        $mate_orderbys_num = $orderby_keys['value_num'];

        if (in_array($orderby, $mate_orderbys_num)) {
            $query->set('orderby', 'meta_value_num');
            $query->set('meta_key', $orderby);
        } elseif (in_array($orderby, $mate_orderbys)) {
            $query->set('orderby', 'meta_value');
            $query->set('meta_key', $orderby);
        } else {
            $query->set('orderby', $orderby);
        }
    }

    //帖子状态
    global $wp_query;
    $curauth = $wp_query->get_queried_object();

    if (isset($_GET['post_status']) && $query->is_main_query() && (is_super_admin() || (!empty($curauth->ID) && get_current_user_id() === $curauth->ID))) {
        $query->set('post_status', $_GET['post_status']);
    }
}

/**
 * @description: 过滤new WP_Query orderby的args
 * @param {*} $orderby
 * @param {*} $args
 * @return {*}
 */
function zib_query_orderby_filter($orderby, $args = array())
{

    $orderby_keys      = zib_get_query_mate_orderby_keys();
    $mate_orderbys     = $orderby_keys['value'];
    $mate_orderbys_num = $orderby_keys['value_num'];

    if (in_array($orderby, $mate_orderbys_num)) {
        $args['orderby']  = 'meta_value_num';
        $args['meta_key'] = $orderby;
    } elseif (in_array($orderby, $mate_orderbys)) {
        $args['orderby']  = 'meta_value';
        $args['meta_key'] = $orderby;
    } else {
        $args['orderby'] = $orderby;
    }

    if (!isset($args['order'])) {
        $args['order'] = 'DESC';
    }

    return $args;
}

function zib_get_query_mate_orderby_keys()
{
    return apply_filters('query_mate_orderby_keys', array(
        'value_num' => array('score', 'plate_id', 'posts_count', 'reply_count', 'today_reply_count', 'follow_count', 'follow', 'views', 'like', 'favorite', 'zibpay_price', 'zibpay_points_price', 'sales_volume', 'balance', 'points', 'phone_number', 'vip_level', 'level', 'referrer_id'),
        'value'     => array('last_reply', 'last_post', 'last_login'),
    ));
}
